@@ -256,12 +256,6 @@ set_ellipse_colours <- function(ns=1,levels=NA,col=c('yellow','red'),
     out[omit] <- omit.col
     out
 }
-# To be removed. Kept for backwards compatibility in provenance 4.2
-set.ellipse.colours <- function(ns=1,levels=NA,col=c('yellow','red'),
-                                hide=NULL,omit=NULL,omit.col=NA){
-    set_ellipse_colours(ns=ns,levels=levels,col=col,
-                        hide=hide,omit=omit,omit.col=omit.col)
-}
 
 levels2colours <- function(levels=c(0,1),col=c('yellow','red')){
     m <- min(levels,na.rm=TRUE)
